---
title: EpiJS Module - Comp
---
<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents


*   [Idiom][2]
    *   [Parameters][3]
    *   [Examples][4]
    *   [addSub][5]
        *   [Parameters][6]
        *   [Examples][7]
*   [Susceptible][8]
    *   [Parameters][9]
    *   [Examples][10]
    *   [addSub][11]
        *   [Parameters][12]
*   [Infected][13]
    *   [Parameters][14]
    *   [Examples][15]
    *   [addSub][16]
        *   [Parameters][17]
*   [Exposed][18]
    *   [Parameters][19]
    *   [Examples][20]
    *   [addSub][21]
        *   [Parameters][22]
*   [Critical][23]
    *   [Parameters][24]
    *   [Examples][25]
    *   [addSub][26]
        *   [Parameters][27]
*   [Hospitalized][28]
    *   [Parameters][29]
    *   [Examples][30]
    *   [addSub][31]
        *   [Parameters][32]
*   [Dead][33]
    *   [Parameters][34]
    *   [Examples][35]
    *   [addSub][36]
        *   [Parameters][37]
*   [Vaccinated][38]
    *   [Parameters][39]
    *   [Examples][40]
    *   [addSub][41]
        *   [Parameters][42]
*   [Recovered][43]
    *   [Parameters][44]
    *   [Examples][45]
    *   [addSub][46]
        *   [Parameters][47]

# Comp
EpiJS module for creating compartments, which can be combined into models.

Import it with:
```javascript
       const comp = require('@epispot/epijs').comp
```
## Idiom

Class for a custom compartments.

### Parameters

*   `equation` **[String][48]** The equation for the compartment. This defines what to run to get a new value for the next day in the model. Use any variable in the equation (1 char max), but when making this a model, you need to define this in the key.
    If using other compartment classes, they each have their own corresponding variable:*   'S' - Susceptible
    *   'E' - Exposed
    *   'I' - Infectious
    *   'R' - Recovered
    *   'D' - Dead
    *   'C' - Critical
    *   'H' - Hospitalized
    *   'V' - Vaccinated
    *   'w' - Reserved for stochastic models. If put, it will be replaced with a random number generated from the gaussian distribution.

### Examples

```javascript
let susceptible = new Idiom("S-(B*S*I)")
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

#### Examples

```javascript
let infected = new Idiom("I+((B*S*I)/p)")

infected.addSub("Asymptomatic", 10) // 10% of the infected population are asymptomatic.
```

## Susceptible

Class for Suscepible compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments This is multiplied by the current susceptible population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "S" as the id. This parameter is useful
    if you want to model a disease with re-susceptibility.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic. You can still pass in your normal equation, and epijs will
    auto generate the equations from what you pass in.

### Examples

```javascript
// Note that you can pass in a number as a rate too, 
     // but we use a string because we want to multiply 
     // by other compartment populations. This applies to the prev parameter too. 
     let S = new Susceptible(["I*0.4/N"], [], true)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Infected

Class for Infected compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments This is multiplied by the current infected population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "I" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations. We do actually do this for the prev parameter, though.
     let I = new Infected([0.3], [["S", "I*0.4/N"]], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Exposed

Class for Exposed compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments This is multiplied by the current exposed population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "E" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations. We do actually do this for the prev parameter, though.
     let E = new Exposed([1/14], ["S*0.4/N"], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Critical

Class for Critical compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments This is multiplied by the current critical population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "C" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations.
     let C = new Critical([0.14, 0.1], [["H", 0.3]], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Hospitalized

Class for Hospitalized compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments This is multiplied by the current hospitalized population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "H" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations.
     let H = new Hospitalized([0.3], [["I", 0.1], ["E", 0.2]], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Dead

Class for the Dead compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments. This is multiplied by the current dead population.
    Useful if you want to have a dead population that can also be the walking dead.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "D" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations. We do actually do this for the prev parameter, though.
     let D = new Dead([0.3], [["I", 0.3]], false) // This disease also gives you a 3/10 chance to come alive after death.
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Vaccinated

Class for Vaccinated compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments, good if the vaccine isn't 100% effective. This is multiplied by the current vaccinated population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "V" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations. We do actually do this for the prev parameter, though.
     let I = new Infected([0.001], ["S*0.4"], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

## Recovered

Class for Recovered compartment.

### Parameters

*   `next` **[Array][50]** List of rates of the next compartments, good if the vaccine isn't 100% effective. This is multiplied by the current vaccinated population.
*   `prev` **[Array][50]** List of rates of the previous compartments, which include sub-arrays
    with the compartment id (one letter only), as a string, and the rate for the compartment.
    If reffering to this compartment's population, use "V" as the id.
*   `stochastic` **[Boolean][51]** If true, the compartment will be stochastic.

### Examples

```javascript
// Note that you can pass in a string as a rate too, 
     // but we use a number in this case because we don't need to multiply 
     // by other compartment populations. We do actually do this for the prev parameter, though.
     let R = new Recovered([ ], [["I", 0.1]], false)
```

### addSub

Add a subcompartment to this compartment.

#### Parameters

*   `name` **[String][48]** Name of sub-compartment.
*   `percentage` **[Number][49]** Percentage of the total compartment population to be in the sub-compartmnet. This will not affect the population of the parent compartment or any other sub-compartment.

[1]: #math

[2]: #idiom

[3]: #parameters

[4]: #examples

[5]: #addsub

[6]: #parameters-1

[7]: #examples-1

[8]: #susceptible

[9]: #parameters-2

[10]: #examples-2

[11]: #addsub-1

[12]: #parameters-3

[13]: #infected

[14]: #parameters-4

[15]: #examples-3

[16]: #addsub-2

[17]: #parameters-5

[18]: #exposed

[19]: #parameters-6

[20]: #examples-4

[21]: #addsub-3

[22]: #parameters-7

[23]: #critical

[24]: #parameters-8

[25]: #examples-5

[26]: #addsub-4

[27]: #parameters-9

[28]: #hospitalized

[29]: #parameters-10

[30]: #examples-6

[31]: #addsub-5

[32]: #parameters-11

[33]: #dead

[34]: #parameters-12

[35]: #examples-7

[36]: #addsub-6

[37]: #parameters-13

[38]: #vaccinated

[39]: #parameters-14

[40]: #examples-8

[41]: #addsub-7

[42]: #parameters-15

[43]: #recovered

[44]: #parameters-16

[45]: #examples-9

[46]: #addsub-8

[47]: #parameters-17

[48]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[49]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[50]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[51]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean
